@@ -5,6 +5,8 @@ use strict;
 use utf8;
 
 use v5.22;
+use feature qw(postderef);
+no warnings qw(experimental::postderef);
 
 use warnings;
 no warnings;
@@ -72,7 +74,7 @@ about this.
 use vars qw($VERSION $EXCLUDE_CPANPLUS @EXPORT @prereqs);
 
 
-$VERSION = '2.001_001';
+$VERSION = '2.001_002';
 
 @EXPORT = qw( prereq_ok );
 
